import webbrowser, subprocess, re
from gi.repository import Gtk, GLib, Gdk, Adw

@Gtk.Template(resource_path='/ru/eepm/PlayGUI/widgets/errordialog.ui')
class ErrorDialog(Adw.Dialog):
    __gtype_name__ = 'ErrorDialog'
    textview = Gtk.Template.Child()

    tg_button = Gtk.Template.Child()
    gh_button = Gtk.Template.Child()

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self.textbuffer = self.textview.get_buffer()

        self.error = None

        self.tg_button.connect("activated", self.on_tg_clicked)
        self.gh_button.connect("activated", self.on_gh_clicked)

    def append_log(self, text):
        self.textbuffer.set_text(text)
        self.textview.scroll_to_mark(self.textbuffer.get_insert(), 0, False, 0.0, 1.0)  # Прокручиваем к курсору

    def present_error(self, win, error):
        self.error = None
        self.build_log(error)
        self.append_log(self.error)
        self.present(win)

    def build_log(self, error):
        separator = "_________________"
        distro_info = subprocess.run(
            ["epm", "print", "info"],
            capture_output=True, text=True, check=True).stdout

        seen = set()
        filtered_error_lines = [
            line for line in error.splitlines() if '%' not in line and not (line in seen or seen.add(line))
        ]

        filtered_error = '\n'.join(filtered_error_lines)

        filtered_error = re.sub(r'\n{3,}', '\n\n', filtered_error)

        if filtered_error_lines and "command:" in filtered_error_lines[0].lower():
            first_line = filtered_error_lines[0]
            self.error = f"{first_line}\n{separator}\n{distro_info}\n{separator}\n" + '\n'.join(
                filtered_error.splitlines()[-30:])
        else:
            self.error = f"{distro_info}\n{separator}\n" + '\n'.join(filtered_error.splitlines()[-30:])

    def copy_error(self):
        display = Gdk.Display.get_default()
        clipboard = display.get_clipboard()
        clipboard.set(self.error)

    def on_tg_clicked(self, button):
        self.copy_error()
        webbrowser.open("https://t.me/useepm")

    def on_gh_clicked(self, button):
        self.copy_error()
        webbrowser.open("https://github.com/Etersoft/eepm/issues")